==> mingw-w64-clang-aarch64-gnuradio-3.10.11.0-11-any.pkg.tar.zst: clangarm64/share/doc/gnuradio-3.10.11.0/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "GNU Radio C++ API Reference", "index.html", [
    [ "Components", "page_components.html", "page_components" ],
    [ "License", "License.html", null ],
    [ "Release Process Documentation", "page_releasing.html", [
      [ "Preparation", "page_releasing.html#Preparation", null ],
      [ "Tagging", "page_releasing.html#Release", null ],
      [ "Of Archives", "page_releasing.html#Creation", null ]
    ] ],
    [ "Build Instructions and Information", "build_guide.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", "namespacemembers_type" ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", "namespacemembers_eval" ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", "functions_type" ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Properties", "functions_prop.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", "globals_vars" ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"ConstellationDisplayPlot_8h.html",
"agc3__cc__pydoc__template_8h.html#aabcda032df7125c695612afb25d50ba8",
"atsc__randomizer__pydoc__template_8h.html#a018632efca73ff7a5287cf52b1105135",
"block__detail__pydoc__template_8h.html#ad741dc3470cef825a67a4c4d9b4d92c9",
"build-CLANGARM64_2gr-blocks_2python_2blocks_2bindings_2pydoc__macros_8h.html#afa7cf06549cf7fd295f622ef6f376357",
"burst__tagger_8h_source.html",
"classConstellationDisplayForm.html#a2823ef966cee912b2cbf13984dc071dc",
"classDisplayPlot.html#adced30b44aac55b5473ed92a861c24bb",
"classFreqDisplayForm.html#ab059f732654e647ff50b2324ccfe28d8",
"classLineWidthMenu.html#a4e0fd0268d6b13d35c9e3c355c22a993",
"classTimeControlPanel.html#ae7362d583aff237d1a83a9474460f8d3",
"classVectorDisplayPlot.html#a419307004cdf3ba027691c0764f6dc04",
"classgr_1_1analog_1_1agc2__cc.html#a459b870507f8420157155e6bc64fcdd0",
"classgr_1_1analog_1_1kernel_1_1agc__ff.html#a752deb5e5d7635ef03556e6d430a887f",
"classgr_1_1basic__block.html#af3a5056e2de6b3e561c02f2de37de44c",
"classgr_1_1blocks_1_1and__blk.html",
"classgr_1_1blocks_1_1ctrlport__probe2__s.html",
"classgr_1_1blocks_1_1message__strobe__random.html#a0ff74a298e0cf409dabe63b14b99adba",
"classgr_1_1blocks_1_1tag__debug.html#a58d634fe5b124a3b842078b554fffdfc",
"classgr_1_1buffer__double__mapped.html#a4e581f90551a3ac5de1d7425b7b055a5",
"classgr_1_1digital_1_1adaptive__algorithm.html#a23536d8333087af0da113e0aff24f8ab",
"classgr_1_1digital_1_1constellation__bpsk.html#a80215bc28e7be4b0bb38b1b3a78654c0",
"classgr_1_1digital_1_1glfsr__source__b.html",
"classgr_1_1digital_1_1msk__timing__recovery__cc.html#acc57869ac653083218f25ded1cac4995",
"classgr_1_1digital_1_1symbol__sync__cc.html#afe4b16670fcf5e71c3282cd4762ac142",
"classgr_1_1dtv_1_1dvbt__bit__inner__interleaver.html",
"classgr_1_1fec_1_1code_1_1polar__common.html#adcb9476e3f437f427d763814381bee0b",
"classgr_1_1fec_1_1tpc__decoder.html#a91ed2ddf6aa73eb271d6e8231f7cb815",
"classgr_1_1filter_1_1freq__xlating__fir__filter.html#a7c54ab3a48e8db3f8717a135be040db0",
"classgr_1_1filter_1_1kernel_1_1pfb__arb__resampler__ccc.html#a06bb98d48c99e45b3f36dd95bdbd1f83",
"classgr_1_1filter_1_1single__pole__iir.html#a5f02362d24af0e1cc955d32c3e82adfe",
"classgr_1_1iio_1_1device__sink.html#a04d0a5ca52ecd9cab96ffa858717cf05",
"classgr_1_1msg__accepter.html#a1032a8f3bf410b7670bc9af0c7c6d7ad",
"classgr_1_1qtgui_1_1ber__sink__b.html#a6a670553381933476126c820caa03a20",
"classgr_1_1qtgui_1_1eye__sink__f.html#ad0a17ef061f38d8e0adee502343d0a08",
"classgr_1_1qtgui_1_1histogram__sink__f.html#ad73087a5d4587d1f0f1524e3df7e406f",
"classgr_1_1qtgui_1_1time__raster__sink__f.html#a6d9764d819fa106484ed54b40282960d",
"classgr_1_1qtgui_1_1vector__sink__f.html#a7cca97a9247ddbe46fab0a0cfea4c190",
"classgr_1_1soapy_1_1block.html#a2fa3ac00cebd970648557800316bcd1a",
"classgr_1_1trellis_1_1fsm.html",
"classgr_1_1uhd_1_1rfnoc__fir__filter.html",
"classgr_1_1vocoder_1_1alaw__encode__sb.html#a3809f75c265cccb156a18780ee3c0eaa",
"classpmt_1_1pmt__base.html#a61dd226e01a41e77e6cfce6a189db3b0",
"classrpcextractor__base.html#abce1c12dd70e7710f0f56a9ea0732a0b",
"complex__to__mag__squared__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
"conv__bit__corr__bb__pydoc__template_8h.html#a2519df3679698aa32727f13422dda568",
"ctcss__squelch__ff__pydoc__template_8h.html#a353989e07d5bb1e096dc9f4340382e93",
"dictionary__logger__backend__pydoc__template_8h.html#ac5d45ec8141a7f73b1cf8769f12628ee",
"dir_d4283fb4a9786802ef66f4a468443963.html",
"dvbt2__p1insertion__cc__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
"eye__sink__c__pydoc__template_8h.html#a7fc5926f3ddd4c40c64d436ee2ac778a",
"file__sink__base__pydoc__template_8h.html#a0eacc51c6fac64d6a20b4a43709e9794",
"fmcomms2__sink_8h_source.html",
"functions_func_e.html",
"glfsr__pydoc__template_8h_source.html",
"group__byte__operators__blk.html",
"hilbert__fc_8h_source.html",
"keep__one__in__n__pydoc__template_8h.html#accbf1797ded790b0d07879591fe50dd1",
"maxstar_8h.html#a2900d511872eae2e209d6a7000819871",
"msg__accepter__msgq_8h.html",
"namespacegr_1_1blocks.html#a264a9b53a1cfc6a3ebd5f100d584e1e6",
"namespacegr_1_1dtv.html#a35dea4c78a05851f4beae107d010e26aa2fb37e069147368fa85412c5fcb1301f",
"namespacegr_1_1paths.html",
"namespacemembers_func_t.html",
"namespacepmt.html#aca8481de03cadd06637755b1216ca93c",
"or__blk_8h_source.html",
"pdu__pydoc__template_8h.html#a44588f34e5de97b643c15a7c9a23e785",
"pfb__clock__sync__ccf__pydoc__template_8h.html#ad8e44250ab9f662ad4327374536a66be",
"pmt__pydoc__template_8h.html#a2dabd6b4ffbf7f90474e07404f33a159",
"pmt__serial__tags_8h.html#abdf3c401a44b88c89208285f00d6643fa9769671df8aa2d2f9c93ba3f7e02caa2",
"probe__signal__v_8h_source.html",
"regenerate__bb__pydoc__template_8h.html#aabdf2fefa556dcab6e636326da6fb852",
"rfnoc__tx__radio__pydoc__template_8h.html#ab46c422b9cb366d5615149ca1e2f457f",
"short__to__float__pydoc__template_8h.html#a62add767a292b37e183222008f5db22f",
"squelch__base__ff__pydoc__template_8h.html#addaf9707ce0a07f95ebf581d5467df8e",
"structrpcbasic__register__set.html#ad019d29e0e1fadaa6d9d8b735ee69ba2",
"tagged__encoder__pydoc__template_8h.html#a5ac6552bc2c17a275fc9105717d59c2f",
"time__raster__sink__f__pydoc__template_8h.html#aef39ef766fd406ff6bed0b636ddc5c6d",
"ulaw__decode__bs_8h.html",
"vector__sink__f__pydoc__template_8h.html#ac12fac5d76f23f9f51aff212dad5bdc5"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';

==> mingw-w64-clang-aarch64-gnuradio-3.10.12.0-2-any.pkg.tar.zst: clangarm64/share/doc/gnuradio-3.10.12.0/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "GNU Radio C++ API Reference", "index.html", [
    [ "Components", "page_components.html", "page_components" ],
    [ "License", "License.html", null ],
    [ "Release Process Documentation", "page_releasing.html", [
      [ "Preparation", "page_releasing.html#Preparation", null ],
      [ "Tagging", "page_releasing.html#Release", null ],
      [ "Of Archives", "page_releasing.html#Creation", null ]
    ] ],
    [ "Build Instructions and Information", "build_guide.html", null ],
    [ "Topics", "topics.html", "topics" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", "namespacemembers_func" ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", "namespacemembers_type" ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", "namespacemembers_eval" ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", "functions_type" ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Properties", "functions_prop.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", null ],
        [ "Variables", "globals_vars.html", "globals_vars" ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"ConstellationDisplayPlot_8h.html",
"agc3__cc__pydoc__template_8h.html#aabcda032df7125c695612afb25d50ba8",
"atsc__randomizer__pydoc__template_8h.html#a018632efca73ff7a5287cf52b1105135",
"block__detail__pydoc__template_8h.html#ad741dc3470cef825a67a4c4d9b4d92c9",
"build-CLANGARM64_2gr-blocks_2python_2blocks_2bindings_2pydoc__macros_8h.html#afa7cf06549cf7fd295f622ef6f376357",
"burst__tagger_8h_source.html",
"classConstellationDisplayForm.html#a2823ef966cee912b2cbf13984dc071dc",
"classDisplayPlot.html#adced30b44aac55b5473ed92a861c24bb",
"classFreqDisplayForm.html#ab059f732654e647ff50b2324ccfe28d8",
"classLineWidthMenu.html#a4e0fd0268d6b13d35c9e3c355c22a993",
"classTimeControlPanel.html#ae7362d583aff237d1a83a9474460f8d3",
"classVectorDisplayPlot.html#a419307004cdf3ba027691c0764f6dc04",
"classgr_1_1analog_1_1agc2__cc.html#a459b870507f8420157155e6bc64fcdd0",
"classgr_1_1analog_1_1kernel_1_1agc__ff.html#a752deb5e5d7635ef03556e6d430a887f",
"classgr_1_1basic__block.html#af3a5056e2de6b3e561c02f2de37de44c",
"classgr_1_1blocks_1_1and__blk.html",
"classgr_1_1blocks_1_1ctrlport__probe2__s.html",
"classgr_1_1blocks_1_1message__strobe__random.html#a0ff74a298e0cf409dabe63b14b99adba",
"classgr_1_1blocks_1_1tag__debug.html#a58d634fe5b124a3b842078b554fffdfc",
"classgr_1_1buffer__double__mapped.html#a4e581f90551a3ac5de1d7425b7b055a5",
"classgr_1_1digital_1_1adaptive__algorithm.html#a23536d8333087af0da113e0aff24f8ab",
"classgr_1_1digital_1_1constellation__bpsk.html#a80215bc28e7be4b0bb38b1b3a78654c0",
"classgr_1_1digital_1_1glfsr__source__b.html",
"classgr_1_1digital_1_1msk__timing__recovery__cc.html#acc57869ac653083218f25ded1cac4995",
"classgr_1_1digital_1_1symbol__sync__cc.html#afe4b16670fcf5e71c3282cd4762ac142",
"classgr_1_1dtv_1_1dvbt__bit__inner__interleaver.html",
"classgr_1_1fec_1_1code_1_1polar__common.html#adcb9476e3f437f427d763814381bee0b",
"classgr_1_1fec_1_1tpc__decoder.html#a91ed2ddf6aa73eb271d6e8231f7cb815",
"classgr_1_1filter_1_1freq__xlating__fir__filter.html#a7c54ab3a48e8db3f8717a135be040db0",
"classgr_1_1filter_1_1kernel_1_1pfb__arb__resampler__ccc.html#a06bb98d48c99e45b3f36dd95bdbd1f83",
"classgr_1_1filter_1_1single__pole__iir.html#aa8d14823d7649449309387443c133615",
"classgr_1_1iio_1_1device__sink.html#a04d0a5ca52ecd9cab96ffa858717cf05",
"classgr_1_1msg__accepter.html#a1032a8f3bf410b7670bc9af0c7c6d7ad",
"classgr_1_1qtgui_1_1ber__sink__b.html#a6a670553381933476126c820caa03a20",
"classgr_1_1qtgui_1_1eye__sink__f.html#ad0a17ef061f38d8e0adee502343d0a08",
"classgr_1_1qtgui_1_1histogram__sink__f.html#ad73087a5d4587d1f0f1524e3df7e406f",
"classgr_1_1qtgui_1_1time__raster__sink__f.html#a6d9764d819fa106484ed54b40282960d",
"classgr_1_1qtgui_1_1vector__sink__f.html#a7cca97a9247ddbe46fab0a0cfea4c190",
"classgr_1_1soapy_1_1block.html#a2fa3ac00cebd970648557800316bcd1a",
"classgr_1_1trellis_1_1fsm.html",
"classgr_1_1uhd_1_1rfnoc__duc.html#a17bdf06529d229806eefed70149180cc",
"classgr_1_1vocoder_1_1alaw__decode__bs.html#aec1a4c451c9057ea31a318ae531c8a8c",
"classpmt_1_1pmt__base.html#a4dff1d4b51e49eb4474b3bb938b8e9b9",
"classrpcextractor__base.html#afb9a96dc63c5144792ca5e086476818f",
"complex__to__mag__squared__pydoc__template_8h_source.html",
"conv__bit__corr__bb__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
"ctcss__squelch__ff__pydoc__template_8h.html#a6dc864432aa28f5358748b9a75fd9361",
"dictionary__logger__backend__pydoc__template_8h_source.html",
"dir_d0df2b74cf468c679c2d810febf4db4f.html",
"dvbt2__p1insertion__cc__pydoc__template_8h.html#ac6338bfa6c3600933d96dbab1358198f",
"eye__sink__c__pydoc__template_8h.html#a81990ccc681daa2081282e41990430e6",
"file__sink__base__pydoc__template_8h.html#a89efc4cc990972e0ab92b34c277b9821",
"fmcomms2__sink__f32c__pydoc__template_8h.html#a2a1b37c5a97a55c6449e7b8f935094c4",
"functions_func_g.html",
"glfsr__source__b__pydoc__template_8h.html",
"group__coding__blk.html",
"hilbert__fc__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d",
"keep__one__in__n__pydoc__template_8h_source.html",
"maxstar_8h.html#a2c320230820ada5cf49c1932925ac6fc",
"msg__accepter__pydoc__template_8h.html",
"namespacegr_1_1blocks.html#a2da706db5e765a2753bcfe47af7e2112",
"namespacegr_1_1dtv.html#a35dea4c78a05851f4beae107d010e26aa309ee473cb6a05ac8341f83798f2fd12",
"namespacegr_1_1paths.html#a0a63932f3295c2519ab6d96dd94a6871",
"namespacemembers_g.html",
"namespacepmt.html#ad036139df4d306b1547307bd22ce6208",
"osx__impl_8h.html",
"pdu__pydoc__template_8h.html#a66835b07b591aef5524786a0faf59706",
"pfb__clock__sync__ccf__pydoc__template_8h_source.html",
"pmt__pydoc__template_8h.html#a2e972576b7af59553507af5d1ecd32be",
"pmt__serial__tags_8h.html#abdf3c401a44b88c89208285f00d6643fab9dd89f1ce8ffa07c84543ca7ac758db",
"protocol__formatter__async_8h.html",
"rep__msg__sink__pydoc__template_8h.html#a2315145bc34c097d964acfa640229538",
"rfnoc__tx__radio__pydoc__template_8h.html#af17c3b4b4f030cab9bd18503f077a9f2",
"short__to__float__pydoc__template_8h_source.html",
"sro__model__pydoc__template_8h.html#a159be69a980c7393012cf69d67e11904",
"structrpcbasic__register__trigger.html#a895792c3924627295fca7ea1dbbd0e82",
"tagged__file__sink_8h.html",
"time__sink__c_8h_source.html",
"ulaw__decode__bs__pydoc__template_8h.html#adef71bf24863902abf7b387c03f3a23c",
"vector__sink__f__pydoc__template_8h.html#adff873daa7fcd985ca0061a4611f32bb"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
